# Manifest

::: geneva.manifest.mgr.GenevaManifest

::: geneva.manifest.builder.PipManifestBuilder
    options:
        inherited_members: true

::: geneva.manifest.builder.CondaManifestBuilder
    options:
        inherited_members: true

::: geneva.manifest.builder.SiteManifestBuilder
    options:
        inherited_members: true
